#
# spec file for package ghc-cryptohash-sha1
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cryptohash-sha1
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.11.101.0
Release:        8.1
Summary:        Fast, pure and practical SHA-1 implementation
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/6.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-SHA-devel
BuildRequires:  ghc-SHA-prof
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-base16-bytestring-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
A practical incremental and one-pass, pure API to the
<https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm> (including
<https://en.wikipedia.org/wiki/HMAC HMAC> support) with performance close to
the fastest implementations available in other languages.

The implementation is made in C with a haskell FFI wrapper that hides the C
implementation.

NOTE: This package has been forked off 'cryptohash-0.11.7' because the
'cryptohash' package has been deprecated and so this package continues to
satisfy the need for a lightweight package providing the SHA1 hash algorithm
without any dependencies on packages other than 'base' and 'bytestring'.

Consequently, this package can be used as a drop-in replacement for
'cryptohash''s "Crypto.Hash.SHA1" module, though with a clearly smaller
footprint.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Jan  1 2025 Peter Simons <psimons@suse.com>
- Update cryptohash-sha1 to version 0.11.101.0 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Jun 26 2024 Peter Simons <psimons@suse.com>
- Update cryptohash-sha1 to version 0.11.101.0 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Apr 19 2024 Peter Simons <psimons@suse.com>
- Update cryptohash-sha1 to version 0.11.101.0 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Sep 14 2023 Peter Simons <psimons@suse.com>
- Update cryptohash-sha1 to version 0.11.101.0 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Apr  7 2023 Peter Simons <psimons@suse.com>
- Update cryptohash-sha1 to version 0.11.101.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Aug 15 2022 Peter Simons <psimons@suse.com>
- Update cryptohash-sha1 to version 0.11.101.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 15 2021 psimons@suse.com
- Update cryptohash-sha1 to version 0.11.101.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/cryptohash-sha1-0.11.101.0/src/changelog.md
* Wed Jun 16 2021 psimons@suse.com
- Update cryptohash-sha1 to version 0.11.100.1 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update cryptohash-sha1 to version 0.11.100.1 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add cryptohash-sha1 at version 0.11.100.1.
